@@ -18,22 +18,25 @@
 
 #include <cstdlib> 
 #include <string>
+#include <cstring>
 
 using namespace std;
 
 #include "SyntaxError.h"
 
+const char *SyntaxError::PREFIX = "Syntax error: ";
+
 const char *
 SyntaxError::what()
-  const
+  const throw()
 {
   // First call: make the message
   if (_message == NULL)
     {
-      int length = strlen(PREFIX) + _reason.size() + 1;
+      int length = ::strlen(PREFIX) + _reason.size() + 1;
       _message = (char*)malloc(sizeof(char)*length);
-      strcpy(_message, PREFIX);
-      strcat(_message, _reason.c_str());
+      ::strcpy(_message, PREFIX);
+      ::strcat(_message, _reason.c_str());
     }
 
   return _message;
